#! /usr/bin/env python

"""
This module draws a speedometer in the position required
with the speed given. It also needs a maximum speed
"""

import math
import cairo


def speedometer(ctx, posx, posy, radius, speed, max_speed):
    # Draw the exterior of the speedometer
    init_arc = -(5 * math.pi) / 4
    finish_arc = math.pi / 4
    ctx.new_sub_path()
    ctx.arc(posx, posy, radius, init_arc, finish_arc)

    ctx.set_source_rgb(1, 1, 1)
    ctx.set_line_width(radius * 0.1)
    ctx.stroke()

    # Draw the interior of the speedometer
    ctx.new_sub_path()
    ctx.arc(posx, posy, radius * 0.5, 0, 2 * math.pi)
    ctx.set_source_rgb(1, 1, 1)
    ctx.set_line_width(radius * 0.1)
    ctx.stroke()

    # Draw the speed number
    speed_text = f"{int(round(speed))}"
    unit_text = "km/h"
    ctx.select_font_face("Sans", cairo.FONT_SLANT_NORMAL,
                         cairo.FONT_WEIGHT_BOLD)

    # The speed itself
    ctx.set_font_size(radius * 0.4)
    x_bearing, y_bearing, width, height, x_advance, y_advance = \
                ctx.text_extents(speed_text)

    x = posx - (width / 2 + x_bearing)
    y = posy
    ctx.move_to(x, y)
    ctx.set_source_rgb(1, 1, 1)
    ctx.show_text(speed_text)
    ctx.stroke()

    # The unit
    ctx.select_font_face("Sans", cairo.FONT_SLANT_NORMAL,
                         cairo.FONT_WEIGHT_NORMAL)

    ctx.set_font_size(radius * 0.15)
    x_bearing, y_bearing, width, height, x_advance, y_advance = \
                ctx.text_extents(unit_text)

    x = posx - (width / 2 + x_bearing)
    y = y + (radius * 0.2)
    ctx.move_to(x, y)
    ctx.show_text(unit_text)
    ctx.stroke()

    # The curve indicating the speed
    point_rad = (6 / max_speed) * speed
    curve_finish_arc = init_arc + ((point_rad * math.pi) / 4)

    ctx.new_sub_path()
    ctx.arc(posx, posy, radius - (radius * 0.2), init_arc, curve_finish_arc)

    ctx.set_source_rgb(1, 0.1, 0.1)
    ctx.set_line_width(radius * 0.3)
    ctx.stroke()
