
import datetime
import re
import xml.etree.ElementTree as ET

from distance import get_meters
from track import Track


def namespace(element):
    m = re.match(r'\{.*\}', element.tag)
    if m:
        name_space = m.group(0)
        name_space = name_space.replace('{', '')
        name_space = name_space.replace('}', '')

        return name_space

    return ''


def parse_gpx(filename, fps=30.0):
    root = ET.parse(filename).getroot()
    print("Default namespace is {}".format(namespace(root)))
    ns = {'def': namespace(root)}
    initial_time = datetime.datetime.strptime(root.find('def:metadata', ns).find('def:time', ns).text, "%Y-%m-%dT%H:%M:%S.%fZ")

    track_data = root.find('def:trk', ns)
    lat = None
    lon = None
    data = Track()
    prev_velocity = 0.0
    prev_elevation = None
    max_speed = 0.0
    max_elevation = 0.0
    min_speed = 9999.0
    min_elevation = 9999.0

    print("Calculating interpolation at {} fps".format(fps))
    for segment in track_data.findall('def:trkseg', ns):
        for point in segment.findall('def:trkpt', ns):
            new_lat = float(point.attrib['lat'])
            new_lon = float(point.attrib['lon'])
            elevation = int(point.find('def:ele', ns).text)

            if not prev_elevation:
                prev_elevation = elevation

            if lat is None:
                lat = new_lat

            if lon is None:
                lon = new_lon

            meters = get_meters(lat, lon, new_lat, new_lon)
            km_hour = meters * 3.6

            if elevation > max_elevation:
                max_elevation = elevation

            if km_hour > max_speed:
                max_speed = km_hour

            if elevation < min_elevation:
                min_elevation = elevation

            if km_hour < min_speed:
                min_speed = km_hour

            # Begin interpolation
            delta_v = (km_hour - prev_velocity) / fps
            delta_e = (elevation - prev_elevation) / fps

            for count in range(0, int(fps)):
                data.add_point(prev_velocity + (count * delta_v), prev_elevation + (count * delta_e))

            # Prepare next iteration
            lat = new_lat
            lon = new_lon
            prev_velocity = km_hour
            prev_elevation = elevation

    data.set_maximum('speed', max_speed)
    data.set_maximum('elevation', max_elevation)
    data.set_minimum('speed', min_speed)
    data.set_minimum('elevation', min_elevation)

    return data
